Crate futures_checkout

Crate futures_checkout 

Checkout objects and return them later.

Structs

OrderedCheckout
The OrderedCheckout object allows multiple consumers to check out and return an object, queueing consumers when the object is not available and waking them in order when it becomes available.
OrderedCheckoutFuture
The future that can be polled to receive the object. To be hidden behind impl Trait once its stable.
ReturnSlot
The ReturnSlot through which the object can be returned to its OrderedCheckout once the consumer is done with it. If a consumer fails to return the object, no other consumer can ever proceed.